@@ -1,41 +1,5 @@
-/****************************************************************************
-**
-** Copyright (C) 2016 The Qt Company Ltd.
-** Contact: https://www.qt.io/licensing/
-**
-** This file is part of the QtGui module of the Qt Toolkit.
-**
-** $QT_BEGIN_LICENSE:LGPL$
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see https://www.qt.io/terms-conditions. For further
-** information use the contact form at https://www.qt.io/contact-us.
-**
-** GNU Lesser General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 3 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL3 included in the
-** packaging of this file. Please review the following information to
-** ensure the GNU Lesser General Public License version 3 requirements
-** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
-**
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 2.0 or (at your option) the GNU General
-** Public license version 3 or any later version approved by the KDE Free
-** Qt Foundation. The licenses are as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file. Please review the following
-** information to ensure the GNU General Public License requirements will
-** be met: https://www.gnu.org/licenses/gpl-2.0.html and
-** https://www.gnu.org/licenses/gpl-3.0.html.
-**
-** $QT_END_LICENSE$
-**
-****************************************************************************/
+// Copyright (C) 2016 The Qt Company Ltd.
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
 
 #include "qpathsimplifier_p.h"
 
@@ -44,7 +8,9 @@
 #include <QtCore/qpoint.h>
 #include <QtCore/qalgorithms.h>
 
-#include <private/qopengl_p.h>
+#if QT_CONFIG(opengl)
+#  include <private/qopengl_p.h>
+#endif
 #include <private/qrbtree_p.h>
 
 QT_BEGIN_NAMESPACE
@@ -164,15 +130,11 @@ QPoint IntersectionPoint::round() const
 
 // Return positive value if 'p' is to the right of the line 'v1'->'v2', negative if left of the
 // line and zero if exactly on the line.
-// The returned value is the sign of the cross product between 'v2-v1' and 'p-v1'.
-inline int pointSideOfLine(const QPoint &p, const QPoint &v1, const QPoint &v2)
+// The returned value is the z-component of the qCross product between 'v2-v1' and 'p-v1',
+// which is twice the signed area of the triangle 'p'->'v1'->'v2' (positive for CW order).
+inline int pointDistanceFromLine(const QPoint &p, const QPoint &v1, const QPoint &v2)
 {
-    qint64 ux = qint64(v2.x()) - v1.x();
-    qint64 uy = qint64(v2.y()) - v1.y();
-    qint64 vx = qint64(p.x()) - v1.x();
-    qint64 vy = qint64(p.y()) - v1.y();
-    qint64 c = (ux * vy) - (uy * vx);
-    return (c > 0) ? 1 : (c < 0) ? -1 : 0;
+    return cross(v2 - v1, p - v1);
 }
 
 IntersectionPoint intersectionPoint(const QPoint &u1, const QPoint &u2,
@@ -343,13 +305,14 @@ private:
         Type type;
         Element *element;
     };
+    friend class QTypeInfo<Event>;
 
     typedef QRBTree<Element *>::Node RBNode;
     typedef BoundingVolumeHierarchy::Node BVHNode;
 
     void initElements(const QVectorPath &path, const QTransform &matrix);
     void removeIntersections();
-    bool connectElements();
+    void connectElements();
     void fillIndices();
     BVHNode *buildTree(Element **elements, int elementCount);
     bool intersectNodes(QDataBuffer<Element *> &elements, BVHNode *elementNode, BVHNode *treeNode);
@@ -381,6 +344,10 @@ private:
     uint m_hints;
 };
 
+} // unnamed namespace
+
+Q_DECLARE_TYPEINFO(PathSimplifier::Event, Q_PRIMITIVE_TYPE);
+
 inline PathSimplifier::BoundingVolumeHierarchy::BoundingVolumeHierarchy()
     : root(nullptr)
     , nodeBlock(nullptr)
@@ -494,17 +461,11 @@ PathSimplifier::PathSimplifier(const QVectorPath &path, QDataBuffer<QPoint> &ver
 {
     m_points->reset();
     m_indices->reset();
-    bool ok = true;
     initElements(path, matrix);
     if (!m_elements.isEmpty()) {
         removeIntersections();
-        ok = connectElements();
-        if (ok)
-            fillIndices();
-    }
-    if (!ok) {
-        m_points->reset();
-        m_indices->reset();
+        connectElements();
+        fillIndices();
     }
 }
 
@@ -689,7 +650,7 @@ void PathSimplifier::removeIntersections()
     m_bvh.free(); // The bounding volume hierarchy is not needed anymore.
 }
 
-bool PathSimplifier::connectElements()
+void PathSimplifier::connectElements()
 {
     Q_ASSERT(!m_elements.isEmpty());
     QDataBuffer<Event> events(m_elements.size() * 2);
@@ -869,8 +830,7 @@ bool PathSimplifier::connectElements()
         }
 
         if (!orderedElements.isEmpty()) {
-            if (orderedElements.size() & 1) // Unexpected path structure
-                return false;
+            Q_ASSERT((orderedElements.size() & 1) == 0);
             int i = 0;
             Element *firstElement = orderedElements.at(0);
             if (m_points->at(firstElement->indices[0]) != eventPoint) {
@@ -896,7 +856,6 @@ bool PathSimplifier::connectElements()
         Q_ASSERT((element->next == nullptr) == (element->previous == nullptr));
     }
 #endif
-    return true;
 }
 
 void PathSimplifier::fillIndices()
@@ -1432,19 +1391,19 @@ bool PathSimplifier::elementIsLeftOf(const Element *left, const Element *right)
         return true;
     if (leftU.x() > qMax(rightL.x(), rightU.x()))
         return false;
-    int d = pointSideOfLine(leftU, rightL, rightU);
+    int d = pointDistanceFromLine(leftU, rightL, rightU);
     // d < 0: left, d > 0: right, d == 0: on top
     if (d == 0) {
-        d = pointSideOfLine(leftL, rightL, rightU);
+        d = pointDistanceFromLine(leftL, rightL, rightU);
         if (d == 0) {
             if (right->degree > Element::Line) {
-                d = pointSideOfLine(leftL, rightL, m_points->at(right->indices[1]));
+                d = pointDistanceFromLine(leftL, rightL, m_points->at(right->indices[1]));
                 if (d == 0)
-                    d = pointSideOfLine(leftL, rightL, m_points->at(right->indices[2]));
+                    d = pointDistanceFromLine(leftL, rightL, m_points->at(right->indices[2]));
             } else if (left->degree > Element::Line) {
-                d = pointSideOfLine(m_points->at(left->indices[1]), rightL, rightU);
+                d = pointDistanceFromLine(m_points->at(left->indices[1]), rightL, rightU);
                 if (d == 0)
-                    d = pointSideOfLine(m_points->at(left->indices[2]), rightL, rightU);
+                    d = pointDistanceFromLine(m_points->at(left->indices[2]), rightL, rightU);
             }
         }
     }
@@ -1464,13 +1423,13 @@ QPair<PathSimplifier::RBNode *, PathSimplifier::RBNode *> PathSimplifier::outerB
         Q_ASSERT(point >= v2 && point <= v1);
         if (point == v1 || point == v2)
             break;
-        int d = pointSideOfLine(point, v1, v2);
+        int d = pointDistanceFromLine(point, v1, v2);
         if (d == 0) {
             if (element->degree == Element::Line)
                 break;
-            d = pointSideOfLine(point, v1, m_points->at(element->indices[1]));
+            d = pointDistanceFromLine(point, v1, m_points->at(element->indices[1]));
             if (d == 0)
-                d = pointSideOfLine(point, v1, m_points->at(element->indices[2]));
+                d = pointDistanceFromLine(point, v1, m_points->at(element->indices[2]));
             Q_ASSERT(d != 0);
         }
         if (d < 0) {
@@ -1496,7 +1455,7 @@ QPair<PathSimplifier::RBNode *, PathSimplifier::RBNode *> PathSimplifier::outerB
         Q_ASSERT(point >= v2 && point <= v1);
         bool equal = (point == v1 || point == v2);
         if (!equal) {
-            int d = pointSideOfLine(point, v1, v2);
+            int d = pointDistanceFromLine(point, v1, v2);
             Q_ASSERT(d >= 0);
             equal = (d == 0 && element->degree == Element::Line);
         }
@@ -1517,7 +1476,7 @@ QPair<PathSimplifier::RBNode *, PathSimplifier::RBNode *> PathSimplifier::outerB
         Q_ASSERT(point >= v2 && point <= v1);
         bool equal = (point == v1 || point == v2);
         if (!equal) {
-            int d = pointSideOfLine(point, v1, v2);
+            int d = pointDistanceFromLine(point, v1, v2);
             Q_ASSERT(d <= 0);
             equal = (d == 0 && element->degree == Element::Line);
         }
@@ -1662,9 +1621,6 @@ void PathSimplifier::sortEvents(Event *events, int count)
     }
 }
 
-} // end anonymous namespace
-
-
 void qSimplifyPath(const QVectorPath &path, QDataBuffer<QPoint> &vertices,
                    QDataBuffer<quint32> &indices, const QTransform &matrix)
 {
@@ -1679,3 +1635,5 @@ void qSimplifyPath(const QPainterPath &path, QDataBuffer<QPoint> &vertices,
 
 
 QT_END_NAMESPACE
+
+#undef Q_FIXED_POINT_SCALE
