@@ -1,44 +1,35 @@
-/****************************************************************************
-**
-** Copyright (C) 2018 The Qt Company Ltd.
-** Contact: https://www.qt.io/licensing/
-**
-** This file is part of the plugins of the Qt Toolkit.
-**
-** $QT_BEGIN_LICENSE:LGPL$
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see https://www.qt.io/terms-conditions. For further
-** information use the contact form at https://www.qt.io/contact-us.
-**
-** GNU Lesser General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 3 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL3 included in the
-** packaging of this file. Please review the following information to
-** ensure the GNU Lesser General Public License version 3 requirements
-** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
-**
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 2.0 or (at your option) the GNU General
-** Public license version 3 or any later version approved by the KDE Free
-** Qt Foundation. The licenses are as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file. Please review the following
-** information to ensure the GNU General Public License requirements will
-** be met: https://www.gnu.org/licenses/gpl-2.0.html and
-** https://www.gnu.org/licenses/gpl-3.0.html.
-**
-** $QT_END_LICENSE$
-**
-****************************************************************************/
+// Copyright (C) 2018 The Qt Company Ltd.
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
 
 // This file is included from qnsview.mm, and only used to organize the code
 
+/*
+    Determines if the text represents one of the "special keys" on macOS
+
+    As a legacy from OpenStep, macOS reserves the range 0xF700-0xF8FF of the
+    Unicode private use area for representing function keys on the keyboard:
+
+      http://www.unicode.org/Public/MAPPINGS/VENDORS/APPLE/CORPCHAR.TXT
+
+      https://developer.apple.com/documentation/appkit/nsevent/specialkey
+
+    These code points are not supposed to have any glyphs associated with them,
+    but since we can't guarantee that the system doesn't have a font that does
+    provide glyphs for this range (Arial Unicode MS e.g.) we need to filter
+    the text of our key events up front.
+*/
+static bool isSpecialKey(const QString &text)
+{
+    if (text.length() != 1)
+        return false;
+
+    const char16_t unicode = text.at(0).unicode();
+    if (unicode >= 0xF700 && unicode <= 0xF8FF)
+        return true;
+
+    return false;
+}
+
 @implementation QNSView (Keys)
 
 - (bool)handleKeyEvent:(NSEvent *)nsevent
@@ -48,16 +39,16 @@
 
     // FIXME: Why is this the top level window and not m_platformWindow?
     QWindow *window = [self topLevelWindow];
-    if (QCocoaWindow *popup = QCocoaIntegration::instance()->activePopupWindow()) {
-        // Popups implicitly grab key events; forward to the active popup if there is one.
-        // This allows popups to e.g. intercept shortcuts and close the popup in response.
-        if (!popup->window()->flags().testFlag(Qt::ToolTip))
-            window = popup->window();
-    }
 
     // We will send a key event unless the input method handles it
     QBoolBlocker sendKeyEventGuard(m_sendKeyEvent, true);
 
+    // Assume we should send key events with text, unless told
+    // otherwise by doCommandBySelector.
+    m_sendKeyEventWithoutText = false;
+
+    bool didInterpretKeyEvent = false;
+
     if (keyEvent.type == QEvent::KeyPress) {
 
         if (m_composingText.isEmpty()) {
@@ -105,6 +96,7 @@
                     m_currentlyInterpretedKeyEvent = nsevent;
                     [self interpretKeyEvents:@[nsevent]];
                     m_currentlyInterpretedKeyEvent = 0;
+                    didInterpretKeyEvent = true;
 
                     // If the last key we sent was dead, then pass the next
                     // key to the IM as well to complete composition.
@@ -117,7 +109,10 @@
 
     bool accepted = true;
     if (m_sendKeyEvent && m_composingText.isEmpty()) {
-        KeyEvent keyEvent(nsevent);
+        // Trust text input system on whether to send the event with text or not,
+        // or otherwise apply heuristics to filter out private use symbols.
+        if (didInterpretKeyEvent ? m_sendKeyEventWithoutText : isSpecialKey(keyEvent.text))
+            keyEvent.text = {};
         qCDebug(lcQpaKeys) << "Sending as" << keyEvent;
         accepted = keyEvent.sendWindowSystemEvent(window);
     }
@@ -278,11 +273,7 @@ KeyEvent::KeyEvent(NSEvent *nsevent)
             key = QAppleKeyMapper::fromCocoaKey(character);
         }
 
-        // Ignore text for the U+F700-U+F8FF range. This is used by Cocoa when
-        // delivering function keys (e.g. arrow keys, backspace, F1-F35, etc.)
-        if (!(modifiers & (Qt::ControlModifier | Qt::MetaModifier))
-            && (character.unicode() < 0xf700 || character.unicode() > 0xf8ff))
-            text = QString::fromNSString(characters);
+        text = QString::fromNSString(characters);
 
         isRepeat = nsevent.ARepeat;
     }
@@ -299,10 +290,9 @@ bool KeyEvent::sendWindowSystemEvent(QWindow *window) const
     case QEvent::KeyPress:
     case QEvent::KeyRelease: {
         static const int count = 1;
-        static const bool tryShortcutOverride = false;
         QWindowSystemInterface::handleExtendedKeyEvent(window, timestamp,
             type, key, modifiers, nativeScanCode, nativeVirtualKey, nativeModifiers,
-            text, isRepeat, count, tryShortcutOverride);
+            text, isRepeat, count);
         // FIXME: Make handleExtendedKeyEvent synchronous
         return QWindowSystemInterface::flushWindowSystemEvents();
     }
