@@ -1,41 +1,5 @@
-/****************************************************************************
-**
-** Copyright (C) 2016 The Qt Company Ltd.
-** Contact: https://www.qt.io/licensing/
-**
-** This file is part of the QtWidgets module of the Qt Toolkit.
-**
-** $QT_BEGIN_LICENSE:LGPL$
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see https://www.qt.io/terms-conditions. For further
-** information use the contact form at https://www.qt.io/contact-us.
-**
-** GNU Lesser General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 3 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL3 included in the
-** packaging of this file. Please review the following information to
-** ensure the GNU Lesser General Public License version 3 requirements
-** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
-**
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 2.0 or (at your option) the GNU General
-** Public license version 3 or any later version approved by the KDE Free
-** Qt Foundation. The licenses are as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file. Please review the following
-** information to ensure the GNU General Public License requirements will
-** be met: https://www.gnu.org/licenses/gpl-2.0.html and
-** https://www.gnu.org/licenses/gpl-3.0.html.
-**
-** $QT_END_LICENSE$
-**
-****************************************************************************/
+// Copyright (C) 2016 The Qt Company Ltd.
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
 
 #include "qdockwidget.h"
 
@@ -62,6 +26,8 @@
 
 QT_BEGIN_NAMESPACE
 
+using namespace Qt::StringLiterals;
+
 extern QString qt_setWindowTitle_helperHelper(const QString&, const QWidget*); // qwidget.cpp
 
 // qmainwindow.cpp
@@ -220,7 +186,7 @@ void QDockWidgetTitleButton::leaveEvent(QEvent *event)
 
 void QDockWidgetTitleButton::paintEvent(QPaintEvent *)
 {
-    QPainter p(this);
+    QStylePainter p(this);
 
     QStyleOptionToolButton opt;
     opt.initFrom(this);
@@ -233,7 +199,7 @@ void QDockWidgetTitleButton::paintEvent(QPaintEvent *)
             opt.state |= QStyle::State_On;
         if (isDown())
             opt.state |= QStyle::State_Sunken;
-        style()->drawPrimitive(QStyle::PE_PanelButtonTool, &opt, &p, this);
+        p.drawPrimitive(QStyle::PE_PanelButtonTool, opt);
     } else if (isDown() || isChecked()) {
         // no frame, but the icon might have explicit pixmaps for QIcon::On
         opt.state |= QStyle::State_On | QStyle::State_Sunken;
@@ -245,7 +211,7 @@ void QDockWidgetTitleButton::paintEvent(QPaintEvent *)
     opt.features = QStyleOptionToolButton::None;
     opt.arrowType = Qt::NoArrow;
     opt.iconSize = dockButtonIconSize();
-    style()->drawComplexControl(QStyle::CC_ToolButton, &opt, &p, this);
+    p.drawComplexControl(QStyle::CC_ToolButton, opt);
 }
 
 /******************************************************************************
@@ -286,8 +252,10 @@ bool QDockWidgetLayout::wmSupportsNativeWindowDeco()
 #if defined(Q_OS_ANDROID)
     return false;
 #else
-    static const bool xcb = !QGuiApplication::platformName().compare(QLatin1String("xcb"), Qt::CaseInsensitive);
-    return !xcb;
+    static const bool xcb = !QGuiApplication::platformName().compare("xcb"_L1, Qt::CaseInsensitive);
+    static const bool wayland =
+            QGuiApplication::platformName().startsWith("wayland"_L1, Qt::CaseInsensitive);
+    return !(xcb || wayland);
 #endif
 }
 
@@ -311,7 +279,7 @@ void QDockWidgetLayout::addItem(QLayoutItem*)
 QLayoutItem *QDockWidgetLayout::itemAt(int index) const
 {
     int cnt = 0;
-    for (int i = 0; i < item_list.count(); ++i) {
+    for (int i = 0; i < item_list.size(); ++i) {
         QLayoutItem *item = item_list.at(i);
         if (item == nullptr)
             continue;
@@ -324,7 +292,7 @@ QLayoutItem *QDockWidgetLayout::itemAt(int index) const
 QLayoutItem *QDockWidgetLayout::takeAt(int index)
 {
     int j = 0;
-    for (int i = 0; i < item_list.count(); ++i) {
+    for (int i = 0; i < item_list.size(); ++i) {
         QLayoutItem *item = item_list.at(i);
         if (item == nullptr)
             continue;
@@ -341,7 +309,7 @@ QLayoutItem *QDockWidgetLayout::takeAt(int index)
 int QDockWidgetLayout::count() const
 {
     int result = 0;
-    for (int i = 0; i < item_list.count(); ++i) {
+    for (int i = 0; i < item_list.size(); ++i) {
         if (item_list.at(i))
             ++result;
     }
@@ -660,13 +628,14 @@ void QDockWidgetPrivate::init()
     layout->setSizeConstraint(QLayout::SetMinAndMaxSize);
 
     QAbstractButton *button = new QDockWidgetTitleButton(q);
-    button->setObjectName(QLatin1String("qt_dockwidget_floatbutton"));
-    QObject::connect(button, SIGNAL(clicked()), q, SLOT(_q_toggleTopLevel()));
+    button->setObjectName("qt_dockwidget_floatbutton"_L1);
+    QObjectPrivate::connect(button, &QAbstractButton::clicked,
+                            this, &QDockWidgetPrivate::toggleTopLevel);
     layout->setWidgetForRole(QDockWidgetLayout::FloatButton, button);
 
     button = new QDockWidgetTitleButton(q);
-    button->setObjectName(QLatin1String("qt_dockwidget_closebutton"));
-    QObject::connect(button, SIGNAL(clicked()), q, SLOT(close()));
+    button->setObjectName("qt_dockwidget_closebutton"_L1);
+    QObject::connect(button, &QAbstractButton::clicked, q, &QDockWidget::close);
     layout->setWidgetForRole(QDockWidgetLayout::CloseButton, button);
 
     font = QApplication::font("QDockWidgetTitle");
@@ -677,8 +646,8 @@ void QDockWidgetPrivate::init()
     toggleViewAction->setMenuRole(QAction::NoRole);
     fixedWindowTitle = qt_setWindowTitle_helperHelper(q->windowTitle(), q);
     toggleViewAction->setText(fixedWindowTitle);
-    QObject::connect(toggleViewAction, SIGNAL(triggered(bool)),
-                        q, SLOT(_q_toggleView(bool)));
+    QObjectPrivate::connect(toggleViewAction, &QAction::triggered,
+                            this, &QDockWidgetPrivate::toggleView);
 #endif
 
     updateButtons();
@@ -713,7 +682,7 @@ void QDockWidget::initStyleOption(QStyleOptionDockWidget *option) const
     option->verticalTitleBar = l->verticalTitleBar;
 }
 
-void QDockWidgetPrivate::_q_toggleView(bool b)
+void QDockWidgetPrivate::toggleView(bool b)
 {
     Q_Q(QDockWidget);
     if (b == q->isHidden()) {
@@ -743,7 +712,7 @@ void QDockWidgetPrivate::updateButtons()
         = qobject_cast<QAbstractButton*>(dwLayout->widgetForRole(QDockWidgetLayout::FloatButton));
     button->setIcon(q->style()->standardIcon(QStyle::SP_TitleBarNormalButton, &opt, q));
     button->setVisible(canFloat && !hideButtons);
-#ifndef QT_NO_ACCESSIBILITY
+#if QT_CONFIG(accessibility)
     //: Accessible name for button undocking a dock widget (floating state)
     button->setAccessibleName(QDockWidget::tr("Float"));
     button->setAccessibleDescription(QDockWidget::tr("Undocks and re-attaches the dock widget"));
@@ -752,7 +721,7 @@ void QDockWidgetPrivate::updateButtons()
         = qobject_cast <QAbstractButton*>(dwLayout->widgetForRole(QDockWidgetLayout::CloseButton));
     button->setIcon(q->style()->standardIcon(QStyle::SP_TitleBarCloseButton, &opt, q));
     button->setVisible(canClose && !hideButtons);
-#ifndef QT_NO_ACCESSIBILITY
+#if QT_CONFIG(accessibility)
     //: Accessible name for button closing a dock widget
     button->setAccessibleName(QDockWidget::tr("Close"));
     button->setAccessibleDescription(QDockWidget::tr("Closes the dock widget"));
@@ -761,7 +730,7 @@ void QDockWidgetPrivate::updateButtons()
     layout->invalidate();
 }
 
-void QDockWidgetPrivate::_q_toggleTopLevel()
+void QDockWidgetPrivate::toggleTopLevel()
 {
     Q_Q(QDockWidget);
     q->setFloating(!q->isFloating());
@@ -788,7 +757,7 @@ void QDockWidgetPrivate::initDrag(const QPoint &pos, bool nca)
     state = new QDockWidgetPrivate::DragState;
     state->pressPos = pos;
     state->globalPressPos = q->mapToGlobal(pos);
-    state->widgetInitialPos = q->pos();
+    state->widgetInitialPos = q->isFloating() ? q->pos() : q->mapToGlobal(QPoint(0, 0));
     state->dragging = false;
     state->widgetItem = nullptr;
     state->ownWidgetItem = false;
@@ -802,7 +771,7 @@ void QDockWidgetPrivate::initDrag(const QPoint &pos, bool nca)
     tabbed widgets, and false if the dock widget should always be dragged
     alone.
  */
-void QDockWidgetPrivate::startDrag(bool group)
+void QDockWidgetPrivate::startDrag(DragScope scope)
 {
     Q_Q(QDockWidget);
 
@@ -812,7 +781,8 @@ void QDockWidgetPrivate::startDrag(bool group)
     QMainWindowLayout *layout = qt_mainwindow_layout_from_dock(q);
     Q_ASSERT(layout != nullptr);
 
-    state->widgetItem = layout->unplug(q, group);
+    const bool wasFloating = q->isFloating();
+    state->widgetItem = layout->unplug(q, scope);
     if (state->widgetItem == nullptr) {
         /*  Dock widget has a QMainWindow parent, but was never inserted with
             QMainWindow::addDockWidget, so the QMainWindowLayout has no
@@ -830,6 +800,20 @@ void QDockWidgetPrivate::startDrag(bool group)
         layout->restore();
 
     state->dragging = true;
+
+#if QT_CONFIG(draganddrop)
+    if (QMainWindowLayout::needsPlatformDrag()) {
+        Qt::DropAction result =
+                layout->performPlatformWidgetDrag(state->widgetItem, state->pressPos);
+        if (result == Qt::IgnoreAction && !wasFloating) {
+            layout->revert(state->widgetItem);
+            delete state;
+            state = nullptr;
+        } else {
+            endDrag(QDockWidgetPrivate::EndDragMode::LocationChange);
+        }
+    }
+#endif
 }
 
 /*! \internal
@@ -837,7 +821,7 @@ void QDockWidgetPrivate::startDrag(bool group)
     The \a abort parameter specifies that it ends because of programmatic state
     reset rather than mouse release event.
  */
-void QDockWidgetPrivate::endDrag(bool abort)
+void QDockWidgetPrivate::endDrag(EndDragMode mode)
 {
     Q_Q(QDockWidget);
     Q_ASSERT(state != nullptr);
@@ -849,7 +833,11 @@ void QDockWidgetPrivate::endDrag(bool abort)
         Q_ASSERT(mainWindow != nullptr);
         QMainWindowLayout *mwLayout = qt_mainwindow_layout(mainWindow);
 
-        if (abort || !mwLayout->plug(state->widgetItem)) {
+        // if mainWindow is being deleted in an ongoing drag, make it a no-op instead of crashing
+        if (!mwLayout)
+            return;
+
+        if (mode == EndDragMode::Abort || !mwLayout->plug(state->widgetItem)) {
             if (hasFeature(this, QDockWidget::DockWidgetFloatable)) {
                 // This QDockWidget will now stay in the floating state.
                 if (state->ownWidgetItem) {
@@ -881,6 +869,11 @@ void QDockWidgetPrivate::endDrag(bool abort)
                         tabPosition = mwLayout->tabPosition(toDockWidgetArea(dwgw->layoutInfo()->dockPos));
                     }
 #endif
+                    // Reparent, if the drag was out of a dock widget group window
+                    if (mode == EndDragMode::LocationChange) {
+                        if (auto *groupWindow = qobject_cast<QDockWidgetGroupWindow *>(q->parentWidget()))
+                            groupWindow->reparent(q);
+                    }
                 }
                 q->activateWindow();
             } else {
@@ -908,11 +901,15 @@ Qt::DockWidgetArea QDockWidgetPrivate::toDockWidgetArea(QInternal::DockPosition
 
 void QDockWidgetPrivate::setResizerActive(bool active)
 {
+#ifdef Q_OS_WINDOWS
+    Q_UNUSED(active);
+#else
     Q_Q(QDockWidget);
     if (active && !resizer)
         resizer = new QWidgetResizeHandler(q);
     if (resizer)
         resizer->setEnabled(active);
+#endif
 }
 
 bool QDockWidgetPrivate::isAnimating() const
@@ -971,13 +968,22 @@ bool QDockWidgetPrivate::mouseDoubleClickEvent(QMouseEvent *event)
 
         if (event->button() == Qt::LeftButton && titleArea.contains(event->position().toPoint()) &&
             hasFeature(this, QDockWidget::DockWidgetFloatable)) {
-            _q_toggleTopLevel();
+            toggleTopLevel();
             return true;
         }
     }
     return false;
 }
 
+bool QDockWidgetPrivate::isTabbed() const
+{
+    Q_Q(const QDockWidget);
+    QDockWidget *that = const_cast<QDockWidget *>(q);
+    auto *mwLayout = qt_mainwindow_layout_from_dock(that);
+    Q_ASSERT(mwLayout);
+    return mwLayout->isDockWidgetTabbed(q);
+}
+
 bool QDockWidgetPrivate::mouseMoveEvent(QMouseEvent *event)
 {
     bool ret = false;
@@ -1008,7 +1014,8 @@ bool QDockWidgetPrivate::mouseMoveEvent(QMouseEvent *event)
             } else
 #endif
             {
-                startDrag();
+                const DragScope scope = isTabbed() ? DragScope::Group : DragScope::Widget;
+                startDrag(scope);
                 q->grabMouse();
                 ret = true;
             }
@@ -1036,11 +1043,14 @@ bool QDockWidgetPrivate::mouseMoveEvent(QMouseEvent *event)
 
             // Calculate new nativePos based on startPos + mouse delta move.
             const QPoint nativeNewPos = nativeWdgOrgPos + (nativeTo - nativeFrom);
-
             pos = QHighDpiScaling::mapPositionFromNative(nativeNewPos, wdgScreen->handle())
                     - windowMarginOffset;
         } else {
             // Fallback in the unlikely case that source and target screens could not be established
+            qCDebug(lcQpaDockWidgets)
+                    << "QDockWidget failed to find relevant screen info. screenFrom:" << screenFrom
+                    << "screenTo:" << screenTo << " wdgScreen:" << wdgScreen << "orgWdgScreen"
+                    << orgWdgScreen;
             pos = event->globalPosition().toPoint() - state->pressPos - windowMarginOffset;
         }
 
@@ -1069,9 +1079,13 @@ bool QDockWidgetPrivate::mouseMoveEvent(QMouseEvent *event)
 bool QDockWidgetPrivate::mouseReleaseEvent(QMouseEvent *event)
 {
 #if QT_CONFIG(mainwindow)
+    // if we are peforming a platform drag ignore the release here and end the drag when the actual
+    // drag ends.
+    if (QMainWindowLayout::needsPlatformDrag())
+        return false;
 
     if (event->button() == Qt::LeftButton && state && !state->nca) {
-        endDrag();
+        endDrag(EndDragMode::LocationChange);
         return true; //filter out the event
     }
 
@@ -1110,26 +1124,25 @@ void QDockWidgetPrivate::nonClientAreaMouseEvent(QMouseEvent *event)
                 break;
             state->ctrlDrag = (event->modifiers() & Qt::ControlModifier) ||
                               (!hasFeature(this, QDockWidget::DockWidgetMovable) && q->isFloating());
-            startDrag();
+            startDrag(DragScope::Group);
             break;
         case QEvent::NonClientAreaMouseMove:
             if (state == nullptr || !state->dragging)
                 break;
 
-#ifndef Q_OS_MAC
-            if (state->nca) {
-                endDrag();
-            }
+#if !defined(Q_OS_MAC) && !defined(Q_OS_WASM)
+            if (state->nca)
+                endDrag(EndDragMode::LocationChange);
 #endif
             break;
         case QEvent::NonClientAreaMouseButtonRelease:
-#ifdef Q_OS_MAC
+#if defined(Q_OS_MAC) || defined(Q_OS_WASM)
                         if (state)
-                                endDrag();
+                            endDrag(EndDragMode::LocationChange);
 #endif
                         break;
         case QEvent::NonClientAreaMouseButtonDblClick:
-            _q_toggleTopLevel();
+            toggleTopLevel();
             break;
         default:
             break;
@@ -1195,10 +1208,10 @@ void QDockWidgetPrivate::setWindowState(bool floating, bool unplug, const QRect
             return; // this dockwidget can't be redocked
     }
 
-    bool wasFloating = q->isFloating();
+    const bool wasFloating = q->isFloating();
     if (wasFloating) // Prevent repetitive unplugging from nested invocations (QTBUG-42818)
         unplug = false;
-    bool hidden = q->isHidden();
+    const bool hidden = q->isHidden();
 
     if (q->isVisible())
         q->hide();
@@ -1216,7 +1229,9 @@ void QDockWidgetPrivate::setWindowState(bool floating, bool unplug, const QRect
         flags |= Qt::FramelessWindowHint;
     }
 
-    if (unplug)
+    // If we are performing a platform drag the flag is not needed and we want to avoid recreating
+    // the platform window when it would be removed later
+    if (unplug && !QMainWindowLayout::needsPlatformDrag())
         flags |= Qt::X11BypassWindowManagerHint;
 
     q->setWindowFlags(flags);
@@ -1293,15 +1308,13 @@ void QDockWidgetPrivate::setWindowState(bool floating, bool unplug, const QRect
     possible to drag the dock widget when undocking. Starting the drag will undock
     the dock widget, but a second drag will be needed to move the dock widget itself.
 
-    \sa QMainWindow, {Dock Widgets Example}
+    \sa QMainWindow
 */
 
 /*!
     \enum QDockWidget::DockWidgetFeature
 
-    \value DockWidgetClosable   The dock widget can be closed. On some systems the dock
-                                widget always has a close button when it's floating
-                                (for example on MacOS 10.5).
+    \value DockWidgetClosable   The dock widget can be closed.
     \value DockWidgetMovable    The dock widget can be moved between docks
                                 by the user.
     \value DockWidgetFloatable  The dock widget can be detached from the
@@ -1433,9 +1446,12 @@ QDockWidget::DockWidgetFeatures QDockWidget::features() const
     \property QDockWidget::floating
     \brief whether the dock widget is floating
 
-    A floating dock widget is presented to the user as an independent
-    window "on top" of its parent QMainWindow, instead of being
-    docked in the QMainWindow.
+    A floating dock widget is presented to the user as a single, independent
+    window "on top" of its parent QMainWindow, instead of being docked
+    either in the QMainWindow, or in a group of tabbed dock widgets.
+
+    Floating dock widgets can be individually positioned and resized, both
+    programmatically or by mouse interaction.
 
     By default, this property is \c true.
 
@@ -1449,7 +1465,7 @@ void QDockWidget::setFloating(bool floating)
 
     // the initial click of a double-click may have started a drag...
     if (d->state != nullptr)
-        d->endDrag(true);
+        d->endDrag(QDockWidgetPrivate::EndDragMode::Abort);
 
     QRect r = d->undockedGeometry;
     // Keep position when undocking for the first time.
@@ -1504,8 +1520,14 @@ void QDockWidget::changeEvent(QEvent *event)
     QDockWidgetLayout *layout = qobject_cast<QDockWidgetLayout*>(this->layout());
 
     switch (event->type()) {
-    case QEvent::ModifiedChange:
     case QEvent::WindowTitleChange:
+        if (isFloating() && windowHandle() && d->topData() && windowHandle()->isVisible()) {
+            // From QWidget::setWindowTitle(): Propagate window title without signal emission
+            d->topData()->caption = windowHandle()->title();
+            d->setWindowTitle_helper(windowHandle()->title());
+        }
+        Q_FALLTHROUGH();
+    case QEvent::ModifiedChange:
         update(layout->titleArea());
 #ifndef QT_NO_ACTION
         d->fixedWindowTitle = qt_setWindowTitle_helperHelper(windowTitle(), this);
@@ -1531,8 +1553,14 @@ void QDockWidget::closeEvent(QCloseEvent *event)
 {
     Q_D(QDockWidget);
     if (d->state)
-        d->endDrag(true);
-    QWidget::closeEvent(event);
+        d->endDrag(QDockWidgetPrivate::EndDragMode::Abort);
+
+    // For non-closable widgets, don't allow closing, except when the mainwindow
+    // is hidden, as otherwise an application wouldn't be able to be shut down.
+    const QMainWindow *win = qobject_cast<QMainWindow*>(parentWidget());
+    const bool canClose = (d->features & DockWidgetClosable)
+                       || (!win || !win->isVisible());
+    event->setAccepted(canClose);
 }
 
 /*! \reimp */
@@ -1608,7 +1636,7 @@ bool QDockWidget::event(QEvent *event)
         bool onTop = false;
         if (win != nullptr) {
             const QObjectList &siblings = win->children();
-            onTop = siblings.count() > 0 && siblings.last() == (QObject*)this;
+            onTop = siblings.size() > 0 && siblings.last() == (QObject*)this;
         }
 #if QT_CONFIG(tabbar)
         if (!isFloating() && layout != nullptr && onTop)
@@ -1722,6 +1750,10 @@ QAction * QDockWidget::toggleViewAction() const
     invisible). This happens when the widget is hidden or shown, as
     well as when it is docked in a tabbed dock area and its tab
     becomes selected or unselected.
+
+    \note The signal can differ from QWidget::isVisible(). This can be the case, if
+    a dock widget is minimized or tabified and associated to a non-selected or
+    inactive tab.
 */
 
 /*!
