@@ -1,30 +1,5 @@
-/****************************************************************************
-**
-** Copyright (C) 2016 The Qt Company Ltd.
-** Contact: https://www.qt.io/licensing/
-**
-** This file is part of the test suite of the Qt Toolkit.
-**
-** $QT_BEGIN_LICENSE:GPL-EXCEPT$
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see https://www.qt.io/terms-conditions. For further
-** information use the contact form at https://www.qt.io/contact-us.
-**
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3 as published by the Free Software
-** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
-** included in the packaging of this file. Please review the following
-** information to ensure the GNU General Public License requirements will
-** be met: https://www.gnu.org/licenses/gpl-3.0.html.
-**
-** $QT_END_LICENSE$
-**
-****************************************************************************/
+// Copyright (C) 2016 The Qt Company Ltd.
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 #include <QTest>
 #include <QtXml/QtXml>
 #include <QtGui/QFontInfo>
@@ -74,16 +49,12 @@ private slots:
     void gradient();
     void extractFontFamily_data();
     void extractFontFamily();
-    void extractFontSize_data();
-    void extractFontSize();
     void extractBorder_data();
     void extractBorder();
     void noTextDecoration();
     void quotedAndUnquotedIdentifiers();
     void whitespaceValues_data();
     void whitespaceValues();
-    void borderColor_data();
-    void borderColor();
 };
 
 void tst_QCssParser::scanner_data()
@@ -155,7 +126,7 @@ static const char *tokenName(QCss::TokenType t)
 static void debug(const QList<QCss::Symbol> &symbols, int index = -1)
 {
     qDebug() << "all symbols:";
-    for (int i = 0; i < symbols.count(); ++i)
+    for (int i = 0; i < symbols.size(); ++i)
         qDebug() << '(' << i << "); Token:" << tokenName(symbols.at(i).token) << "; Lexem:" << symbols.at(i).lexem();
     if (index != -1)
         qDebug() << "failure at index" << index;
@@ -173,10 +144,10 @@ void tst_QCssParser::scanner()
     QList<QCss::Symbol> symbols;
     QCss::Scanner::scan(QCss::Scanner::preprocess(QString::fromUtf8(inputFile.readAll())), &symbols);
 
-    QVERIFY(symbols.count() > 1);
+    QVERIFY(symbols.size() > 1);
     QCOMPARE(symbols.last().token, QCss::S);
     QCOMPARE(symbols.last().lexem(), QLatin1String("\n"));
-    symbols.remove(symbols.count() - 1, 1);
+    symbols.remove(symbols.size() - 1, 1);
 
     QFile outputFile(output);
     QVERIFY(outputFile.open(QIODevice::ReadOnly|QIODevice::Text));
@@ -188,14 +159,14 @@ void tst_QCssParser::scanner()
         lines.append(line);
     }
 
-    if (lines.count() != symbols.count()) {
+    if (lines.size() != symbols.size()) {
         debug(symbols);
-        QCOMPARE(lines.count(), symbols.count());
+        QCOMPARE(lines.size(), symbols.size());
     }
 
-    for (int i = 0; i < lines.count(); ++i) {
+    for (int i = 0; i < lines.size(); ++i) {
         QStringList l = lines.at(i).split(QChar::fromLatin1('|'));
-        QCOMPARE(l.count(), 2);
+        QCOMPARE(l.size(), 2);
         const QString expectedToken = l.at(0);
         const QString expectedLexem = l.at(1);
         QString actualToken = QString::fromLatin1(tokenName(symbols.at(i).token));
@@ -379,9 +350,9 @@ void tst_QCssParser::expr()
     QVERIFY(parser.testExpr());
     QCOMPARE(parser.parseExpr(&values), parseSuccess);
     if (parseSuccess) {
-        QCOMPARE(values.count(), expectedValues.count());
+        QCOMPARE(values.size(), expectedValues.size());
 
-        for (int i = 0; i < values.count(); ++i) {
+        for (int i = 0; i < values.size(); ++i) {
             QCOMPARE(int(values.at(i).type), int(expectedValues.at(i).type));
             QCOMPARE(values.at(i).variant, expectedValues.at(i).variant);
         }
@@ -400,7 +371,7 @@ void tst_QCssParser::import()
     QVERIFY(parser.testImport());
     QVERIFY(parser.parseImport(&rule));
     QCOMPARE(rule.href, QString("www.kde.org"));
-    QCOMPARE(rule.media.count(), 2);
+    QCOMPARE(rule.media.size(), 2);
     QCOMPARE(rule.media.at(0), QString("print"));
     QCOMPARE(rule.media.at(1), QString("screen"));
 }
@@ -411,7 +382,7 @@ void tst_QCssParser::media()
     QVERIFY(parser.testMedia());
     QCss::MediaRule rule;
     QVERIFY(parser.parseMedia(&rule));
-    QCOMPARE(rule.media.count(), 2);
+    QCOMPARE(rule.media.size(), 2);
     QCOMPARE(rule.media.at(0), QString("print"));
     QCOMPARE(rule.media.at(1), QString("screen"));
     QVERIFY(rule.styleRules.isEmpty());
@@ -434,8 +405,8 @@ void tst_QCssParser::ruleset()
         QVERIFY(parser.testRuleset());
         QCss::StyleRule rule;
         QVERIFY(parser.parseRuleset(&rule));
-        QCOMPARE(rule.selectors.count(), 1);
-        QCOMPARE(rule.selectors.at(0).basicSelectors.count(), 1);
+        QCOMPARE(rule.selectors.size(), 1);
+        QCOMPARE(rule.selectors.at(0).basicSelectors.size(), 1);
         QCOMPARE(rule.selectors.at(0).basicSelectors.at(0).elementName, QString("p"));
         QVERIFY(rule.declarations.isEmpty());
     }
@@ -445,10 +416,10 @@ void tst_QCssParser::ruleset()
         QVERIFY(parser.testRuleset());
         QCss::StyleRule rule;
         QVERIFY(parser.parseRuleset(&rule));
-        QCOMPARE(rule.selectors.count(), 2);
-        QCOMPARE(rule.selectors.at(0).basicSelectors.count(), 1);
+        QCOMPARE(rule.selectors.size(), 2);
+        QCOMPARE(rule.selectors.at(0).basicSelectors.size(), 1);
         QCOMPARE(rule.selectors.at(0).basicSelectors.at(0).elementName, QString("p"));
-        QCOMPARE(rule.selectors.at(1).basicSelectors.count(), 1);
+        QCOMPARE(rule.selectors.at(1).basicSelectors.size(), 1);
         QCOMPARE(rule.selectors.at(1).basicSelectors.at(0).elementName, QString("div"));
         QVERIFY(rule.declarations.isEmpty());
     }
@@ -458,14 +429,14 @@ void tst_QCssParser::ruleset()
         QVERIFY(parser.testRuleset());
         QCss::StyleRule rule;
         QVERIFY(parser.parseRuleset(&rule));
-        QCOMPARE(rule.selectors.count(), 2);
+        QCOMPARE(rule.selectors.size(), 2);
 
-        QCOMPARE(rule.selectors.at(0).basicSelectors.count(), 1);
-        QCOMPARE(rule.selectors.at(0).basicSelectors.at(0).pseudos.count(), 1);
+        QCOMPARE(rule.selectors.at(0).basicSelectors.size(), 1);
+        QCOMPARE(rule.selectors.at(0).basicSelectors.at(0).pseudos.size(), 1);
         QCOMPARE(rule.selectors.at(0).basicSelectors.at(0).pseudos.at(0).name, QString("before"));
 
-        QCOMPARE(rule.selectors.at(1).basicSelectors.count(), 1);
-        QCOMPARE(rule.selectors.at(1).basicSelectors.at(0).pseudos.count(), 1);
+        QCOMPARE(rule.selectors.at(1).basicSelectors.size(), 1);
+        QCOMPARE(rule.selectors.at(1).basicSelectors.at(0).pseudos.size(), 1);
         QCOMPARE(rule.selectors.at(1).basicSelectors.at(0).pseudos.at(0).name, QString("after"));
 
         QVERIFY(rule.declarations.isEmpty());
@@ -717,21 +688,21 @@ void tst_QCssParser::selector()
     QCss::Selector selector;
     QVERIFY(parser.parseSelector(&selector));
 
-    QCOMPARE(selector.basicSelectors.count(), expectedSelector.basicSelectors.count());
-    for (int i = 0; i < selector.basicSelectors.count(); ++i) {
+    QCOMPARE(selector.basicSelectors.size(), expectedSelector.basicSelectors.size());
+    for (int i = 0; i < selector.basicSelectors.size(); ++i) {
         const QCss::BasicSelector sel = selector.basicSelectors.at(i);
         const QCss::BasicSelector expectedSel = expectedSelector.basicSelectors.at(i);
         QCOMPARE(sel.elementName, expectedSel.elementName);
         QCOMPARE(int(sel.relationToNext), int(expectedSel.relationToNext));
 
-        QCOMPARE(sel.pseudos.count(), expectedSel.pseudos.count());
-        for (int i = 0; i < sel.pseudos.count(); ++i) {
+        QCOMPARE(sel.pseudos.size(), expectedSel.pseudos.size());
+        for (int i = 0; i < sel.pseudos.size(); ++i) {
             QCOMPARE(sel.pseudos.at(i).name, expectedSel.pseudos.at(i).name);
             QCOMPARE(sel.pseudos.at(i).function, expectedSel.pseudos.at(i).function);
         }
 
-        QCOMPARE(sel.attributeSelectors.count(), expectedSel.attributeSelectors.count());
-        for (int i = 0; i < sel.attributeSelectors.count(); ++i) {
+        QCOMPARE(sel.attributeSelectors.size(), expectedSel.attributeSelectors.size());
+        for (int i = 0; i < sel.attributeSelectors.size(); ++i) {
             QCOMPARE(sel.attributeSelectors.at(i).name, expectedSel.attributeSelectors.at(i).name);
             QCOMPARE(sel.attributeSelectors.at(i).value, expectedSel.attributeSelectors.at(i).value);
             QCOMPARE(int(sel.attributeSelectors.at(i).valueMatchCriterium), int(expectedSel.attributeSelectors.at(i).valueMatchCriterium));
@@ -789,13 +760,13 @@ void tst_QCssParser::malformedDeclarations()
     QCss::StyleRule rule;
     QVERIFY(parser.parseRuleset(&rule));
 
-    QCOMPARE(rule.selectors.count(), 1);
-    QCOMPARE(rule.selectors.at(0).basicSelectors.count(), 1);
+    QCOMPARE(rule.selectors.size(), 1);
+    QCOMPARE(rule.selectors.at(0).basicSelectors.size(), 1);
     QCOMPARE(rule.selectors.at(0).basicSelectors.at(0).elementName, QString("p"));
 
-    QVERIFY(rule.declarations.count() >= 1);
+    QVERIFY(rule.declarations.size() >= 1);
     QCOMPARE(int(rule.declarations.last().d->propertyId), int(QCss::Color));
-    QCOMPARE(rule.declarations.last().d->values.count(), 1);
+    QCOMPARE(rule.declarations.last().d->values.size(), 1);
     QCOMPARE(int(rule.declarations.last().d->values.at(0).type), int(QCss::Value::Identifier));
     QCOMPARE(rule.declarations.last().d->values.at(0).variant.toString(), QString("green"));
 }
@@ -815,17 +786,17 @@ void tst_QCssParser::invalidAtKeywords()
     QCss::StyleSheet sheet;
     QVERIFY(parser.parse(&sheet));
 
-    QCOMPARE(sheet.styleRules.count() + sheet.nameIndex.count(), 1);
+    QCOMPARE(sheet.styleRules.size() + sheet.nameIndex.size(), 1);
     QCss::StyleRule rule =  (!sheet.styleRules.isEmpty()) ?
             sheet.styleRules.at(0) : *sheet.nameIndex.begin();
 
-    QCOMPARE(rule.selectors.count(), 1);
-    QCOMPARE(rule.selectors.at(0).basicSelectors.count(), 1);
+    QCOMPARE(rule.selectors.size(), 1);
+    QCOMPARE(rule.selectors.at(0).basicSelectors.size(), 1);
     QCOMPARE(rule.selectors.at(0).basicSelectors.at(0).elementName, QString("h1"));
 
-    QCOMPARE(rule.declarations.count(), 1);
+    QCOMPARE(rule.declarations.size(), 1);
     QCOMPARE(int(rule.declarations.at(0).d->propertyId), int(QCss::Color));
-    QCOMPARE(rule.declarations.at(0).d->values.count(), 1);
+    QCOMPARE(rule.declarations.at(0).d->values.size(), 1);
     QCOMPARE(int(rule.declarations.at(0).d->values.at(0).type), int(QCss::Value::Identifier));
     QCOMPARE(rule.declarations.at(0).d->values.at(0).variant.toString(), QString("blue"));
 }
@@ -1170,9 +1141,9 @@ void tst_QCssParser::styleSelector()
     QList<QCss::Declaration> decls = testSelector.declarationsForNode(n);
 
     if (match) {
-        QCOMPARE(decls.count(), 1);
+        QCOMPARE(decls.size(), 1);
         QCOMPARE(int(decls.at(0).d->propertyId), int(QCss::BackgroundColor));
-        QCOMPARE(decls.at(0).d->values.count(), 1);
+        QCOMPARE(decls.at(0).d->values.size(), 1);
         QCOMPARE(int(decls.at(0).d->values.at(0).type), int(QCss::Value::Identifier));
         QCOMPARE(decls.at(0).d->values.at(0).variant.toString(), QString("green"));
     } else {
@@ -1212,11 +1183,11 @@ void tst_QCssParser::specificity()
     QCss::StyleSheet sheet;
     QVERIFY(parser.parse(&sheet));
 
-    QCOMPARE(sheet.styleRules.count() + sheet.nameIndex.count() + sheet.idIndex.count() , 1);
+    QCOMPARE(sheet.styleRules.size() + sheet.nameIndex.size() + sheet.idIndex.size() , 1);
     QCss::StyleRule rule =  (!sheet.styleRules.isEmpty()) ? sheet.styleRules.at(0)
                         :  (!sheet.nameIndex.isEmpty())  ? *sheet.nameIndex.begin()
                         :  *sheet.idIndex.begin();
-    QCOMPARE(rule.selectors.count(), 1);
+    QCOMPARE(rule.selectors.size(), 1);
     QTEST(rule.selectors.at(0).specificity(), "specificity");
 }
 
@@ -1265,15 +1236,15 @@ void tst_QCssParser::specificitySort()
         n.ptr = &e;
         QList<QCss::Declaration> decls = testSelector.declarationsForNode(n);
 
-        QCOMPARE(decls.count(), 2);
+        QCOMPARE(decls.size(), 2);
 
         QCOMPARE(int(decls.at(0).d->propertyId), int(QCss::Color));
-        QCOMPARE(decls.at(0).d->values.count(), 1);
+        QCOMPARE(decls.at(0).d->values.size(), 1);
         QCOMPARE(int(decls.at(0).d->values.at(0).type), int(QCss::Value::Identifier));
         QCOMPARE(decls.at(0).d->values.at(0).variant.toString(), QString("green"));
 
         QCOMPARE(int(decls.at(1).d->propertyId), int(QCss::Color));
-        QCOMPARE(decls.at(1).d->values.count(), 1);
+        QCOMPARE(decls.at(1).d->values.size(), 1);
         QCOMPARE(int(decls.at(1).d->values.at(0).type), int(QCss::Value::Identifier));
         QCOMPARE(decls.at(1).d->values.at(0).variant.toString(), QString("red"));
     }
@@ -1348,7 +1319,7 @@ void tst_QCssParser::rulesForNode()
     QList<QCss::StyleRule> rules = testSelector.styleRulesForNode(n);
 
     QList<QCss::Declaration> decls;
-    for (int i = 0; i < rules.count(); i++) {
+    for (int i = 0; i < rules.size(); i++) {
         const QCss::Selector &selector = rules.at(i).selectors.at(0);
         quint64 negated = 0;
         quint64 cssClass = selector.pseudoClass(&negated);
@@ -1357,7 +1328,7 @@ void tst_QCssParser::rulesForNode()
             decls += rules.at(i).declarations;
     }
 
-    QCOMPARE(decls.count(), declCount);
+    QCOMPARE(decls.size(), declCount);
 
     if (declCount > 0)
         QCOMPARE(decls.at(0).d->values.at(0).variant.toString(), value0);
@@ -1484,14 +1455,14 @@ void tst_QCssParser::pseudoElement()
     n.ptr = &e;
     QList<QCss::StyleRule> rules = testSelector.styleRulesForNode(n);
     QList<QCss::Declaration> decls;
-    for (int i = 0; i < rules.count(); i++) {
+    for (int i = 0; i < rules.size(); i++) {
         const QCss::Selector& selector = rules.at(i).selectors.at(0);
         if (pseudoElement.compare(selector.pseudoElement(), Qt::CaseInsensitive) != 0)
             continue;
         decls += rules.at(i).declarations;
 
     }
-    QCOMPARE(decls.count(), declCount);
+    QCOMPARE(decls.size(), declCount);
 }
 
 void tst_QCssParser::gradient_data()
@@ -1572,9 +1543,9 @@ void tst_QCssParser::gradient()
     QList<QCss::StyleRule> rules = testSelector.styleRulesForNode(n);
     QList<QCss::Declaration> decls = rules.at(0).declarations;
     QCss::ValueExtractor ve(decls);
-    QBrush fg, sfg;
+    QBrush fg, sfg, pfg;
     QBrush sbg, abg;
-    QVERIFY(ve.extractPalette(&fg, &sfg, &sbg, &abg));
+    QVERIFY(ve.extractPalette(&fg, &sfg, &sbg, &abg, &pfg));
     if (type == "linear") {
         QCOMPARE(sbg.style(), Qt::LinearGradientPattern);
         const QLinearGradient *lg = static_cast<const QLinearGradient *>(sbg.gradient());
@@ -1625,7 +1596,7 @@ void tst_QCssParser::extractFontFamily()
     QCss::StyleSheet sheet;
     QVERIFY(parser.parse(&sheet));
 
-    QCOMPARE(sheet.styleRules.count() + sheet.nameIndex.count(), 1);
+    QCOMPARE(sheet.styleRules.size() + sheet.nameIndex.size(), 1);
     QCss::StyleRule rule =  (!sheet.styleRules.isEmpty()) ?
             sheet.styleRules.at(0) : *sheet.nameIndex.begin();
 
@@ -1641,65 +1612,6 @@ void tst_QCssParser::extractFontFamily()
     QTEST(info.family(), "expectedFamily");
 }
 
-void tst_QCssParser::extractFontSize_data()
-{
-    QTest::addColumn<QString>("css");
-    QTest::addColumn<int>("expectedPixelSize");
-    QTest::addColumn<int>("expectedPointSize");
-    QTest::addColumn<qreal>("expectedPointSizeF");
-
-    QTest::newRow("integer point size") << "font-size: 12pt" << -1 << 12 << 12.0;
-    QTest::newRow("float point size round down") << "font-size: 12.3pt" << -1 << 12 << 12.3;
-    QTest::newRow("float point size midpoint") << "font-size: 12.5pt" << -1 << 13 << 12.5;
-    QTest::newRow("float point size round up") << "font-size: 12.7pt" << -1 << 13 << 12.7;
-
-    QTest::newRow("integer pixel size") << "font-size: 12px" << 12 << -1 << -1.0;
-    QTest::newRow("float pixel size round down") << "font-size: 12.3px" << 12 << -1 << -1.0;
-    QTest::newRow("float pixel size midpoint") << "font-size: 12.5px" << 13 << -1 << -1.0;
-    QTest::newRow("float pixel size round up") << "font-size: 12.7px" << 13 << -1 << -1.0;
-
-    QTest::newRow("shorthand integer point size") << "font: 12pt Arial" << -1 << 12 << 12.0;
-    QTest::newRow("shorthand float point size round down") << "font: 12.3pt Arial" << -1 << 12 << 12.3;
-    QTest::newRow("shorthand float point size midpoint") << "font: 12.5pt Arial" << -1 << 13 << 12.5;
-    QTest::newRow("shorthand float point size round up") << "font: 12.7pt Arial" << -1 << 13 << 12.7;
-
-    QTest::newRow("shorthand integer pixel size") << "font: 12px Arial" << 12 << -1 << -1.0;
-    QTest::newRow("shorthand float pixel size round down") << "font: 12.3px Arial" << 12 << -1 << -1.0;
-    QTest::newRow("shorthand float pixel size midpoint") << "font: 12.5px Arial" << 13 << -1 << -1.0;
-    QTest::newRow("shorthand float pixel size round up") << "font: 12.7px Arial" << 13 << -1 << -1.0;
-}
-
-void tst_QCssParser::extractFontSize()
-{
-    QFETCH(QString, css);
-    css.prepend("dummy {");
-    css.append(QLatin1Char('}'));
-
-    QCss::Parser parser(css);
-    QCss::StyleSheet sheet;
-    QVERIFY(parser.parse(&sheet));
-
-    QCOMPARE(sheet.styleRules.size() + sheet.nameIndex.size(), 1);
-    QCss::StyleRule rule = (!sheet.styleRules.isEmpty()) ?
-            sheet.styleRules.at(0) : *sheet.nameIndex.begin();
-
-    const QList<QCss::Declaration> decls = rule.declarations;
-    QVERIFY(!decls.isEmpty());
-    QCss::ValueExtractor extractor(decls);
-
-    int adjustment = 0;
-    QFont font;
-    extractor.extractFont(&font, &adjustment);
-
-    QFETCH(int, expectedPixelSize);
-    QFETCH(int, expectedPointSize);
-    QFETCH(qreal, expectedPointSizeF);
-
-    QCOMPARE(font.pixelSize(), expectedPixelSize);
-    QCOMPARE(font.pointSize(), expectedPointSize);
-    QCOMPARE(font.pointSizeF(), expectedPointSizeF);
-}
-
 void tst_QCssParser::extractBorder_data()
 {
     QTest::addColumn<QString>("css");
@@ -1742,7 +1654,7 @@ void tst_QCssParser::extractBorder()
     QCss::StyleSheet sheet;
     QVERIFY(parser.parse(&sheet));
 
-    QCOMPARE(sheet.styleRules.count() + sheet.nameIndex.count(), 1);
+    QCOMPARE(sheet.styleRules.size() + sheet.nameIndex.size(), 1);
     QCss::StyleRule rule =  (!sheet.styleRules.isEmpty()) ?
             sheet.styleRules.at(0) : *sheet.nameIndex.begin();
     const QList<QCss::Declaration> decls = rule.declarations;
@@ -1772,7 +1684,7 @@ void tst_QCssParser::noTextDecoration()
     QCss::StyleSheet sheet;
     QVERIFY(parser.parse(&sheet));
 
-    QCOMPARE(sheet.styleRules.count() + sheet.nameIndex.count(), 1);
+    QCOMPARE(sheet.styleRules.size() + sheet.nameIndex.size(), 1);
     QCss::StyleRule rule =  (!sheet.styleRules.isEmpty()) ?
             sheet.styleRules.at(0) : *sheet.nameIndex.begin();
     const QList<QCss::Declaration> decls = rule.declarations;
@@ -1797,7 +1709,7 @@ void tst_QCssParser::quotedAndUnquotedIdentifiers()
     QCss::StyleSheet sheet;
     QVERIFY(parser.parse(&sheet));
 
-    QCOMPARE(sheet.styleRules.count() + sheet.nameIndex.count(), 1);
+    QCOMPARE(sheet.styleRules.size() + sheet.nameIndex.size(), 1);
     QCss::StyleRule rule = (!sheet.styleRules.isEmpty()) ?
            sheet.styleRules.at(0) : *sheet.nameIndex.begin();
     const QList<QCss::Declaration> decls = rule.declarations;
@@ -1839,57 +1751,6 @@ void tst_QCssParser::whitespaceValues()
     QCOMPARE(rule.declarations.at(0).d->values.first().toString(), value);
 }
 
-void tst_QCssParser::borderColor_data()
-{
-    QTest::addColumn<QString>("css");
-    QTest::addColumn<QColor>("expectedTopColor");
-    QTest::addColumn<QColor>("expectedRightColor");
-    QTest::addColumn<QColor>("expectedBottomColor");
-    QTest::addColumn<QColor>("expectedLeftColor");
-
-    QTest::newRow("four values") << "border-color: red green blue white" << QColor("red") << QColor("green") << QColor("blue") << QColor("white");
-    QTest::newRow("three values") << "border-color: red green blue" << QColor("red") << QColor("green") << QColor("blue") << QColor("green");
-    QTest::newRow("two values") << "border-color: red green" << QColor("red") << QColor("green") << QColor("red") << QColor("green");
-    QTest::newRow("one value") << "border-color: red" << QColor("red") << QColor("red") << QColor("red") << QColor("red");
-}
-
-void tst_QCssParser::borderColor()
-{
-    QFETCH(QString, css);
-    QFETCH(QColor, expectedTopColor);
-    QFETCH(QColor, expectedRightColor);
-    QFETCH(QColor, expectedBottomColor);
-    QFETCH(QColor, expectedLeftColor);
-
-    css.prepend("dummy {");
-    css.append(QLatin1Char('}'));
-
-    QCss::Parser parser(css);
-    QCss::StyleSheet sheet;
-    QVERIFY(parser.parse(&sheet));
-
-    QCOMPARE(sheet.styleRules.size() + sheet.nameIndex.size(), 1);
-    QCss::StyleRule rule =  (!sheet.styleRules.isEmpty()) ?
-            sheet.styleRules.at(0) : *sheet.nameIndex.begin();
-    const QList<QCss::Declaration> decls = rule.declarations;
-    QVERIFY(decls.size() == 1);
-    QVERIFY(decls[0].d->propertyId == QCss::BorderColor);
-
-    QBrush colors[4];
-
-    decls[0].brushValues(colors);
-    QCOMPARE(colors[QCss::TopEdge].color(), expectedTopColor);
-    QCOMPARE(colors[QCss::RightEdge].color(), expectedRightColor);
-    QCOMPARE(colors[QCss::BottomEdge].color(), expectedBottomColor);
-    QCOMPARE(colors[QCss::LeftEdge].color(), expectedLeftColor);
-
-    //QTBUG-126381 : a second evaluation should give the same results
-    QCOMPARE(colors[QCss::TopEdge].color(), expectedTopColor);
-    QCOMPARE(colors[QCss::RightEdge].color(), expectedRightColor);
-    QCOMPARE(colors[QCss::BottomEdge].color(), expectedBottomColor);
-    QCOMPARE(colors[QCss::LeftEdge].color(), expectedLeftColor);
-}
-
 QTEST_MAIN(tst_QCssParser)
 #include "tst_qcssparser.moc"
 
